@@ -3,7 +3,7 @@ class Gateways:
     """
     Class containing Gateway endpoints.
     """
-    Global = 'https://gw.cmtelecom.com/v1.0/message'    #Global Endpoint URL
+    Global = 'https://gw.messaging.cm.com/v1.0/message' #Global Endpoint URL
     CN = 'https://gw-cn.cmtelecom.com/v1.0/message'     #China Mainland Endpoint URL
     UK = 'https://gw-uk.cmtelecom.com/v1.0/message'     #London Endpoint URL
     ZA = 'https://gw.cmtelecom.co.za/v1.0/message'      #South Africa Endpoint URL
